@@ -44,24 +44,28 @@ ok(@pkg);
 ok($pkg[0]->name);
 
 @pkg = ();
-$i = $db->find_by_name_iter("kernel");
+$i = $db->find_by_name_iter("filesystem");
 ok($i);
 while (my $pkg = $i->next) {
   push @pkg, $pkg;
 }
 if (@pkg) {
   ok($pkg[0]->name);
+} else {
+  skip('package filesystem not installed');
 }
 
 @pkg = ();
 
-$i = $db->find_by_provides_iter("kernel");
+$i = $db->find_by_provides_iter("filesystem");
 ok($i);
 while (my $pkg = $i->next) {
   push @pkg, $pkg;
 }
 if (@pkg) {
   ok($pkg[0]->name);
+} else {
+  skip('package providing filesystem not installed');
 }
 
 @pkg = ();
@@ -70,6 +74,8 @@ foreach my $pkg ($db->find_by_file("/bin/sh")) {
 }
 if (@pkg) {
   ok($pkg[0]->name);
+} else {
+  skip('package with /bin/sh not installed');
 }
 
 @pkg = ();
@@ -79,6 +85,8 @@ foreach my $pkg ($db->find_by_requires("/bin/bash")) {
 if (@pkg) {
   ok($pkg[0]->name);
   ok(not defined $pkg[0]->filename);
+} else {
+  for (1..2) { skip('no package requiring /bin/bash installed') }
 }
 
 my $pkg = RPM2->open_package("test-rpm-1.0-1.noarch.rpm");
